"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureExtendedError = exports.MessageError = exports.TransactionalOutboxInboxError = void 0;
/** An error that was raised from the transactional outbox/inbox library. Includes an error code. */
class TransactionalOutboxInboxError extends Error {
    constructor(message, errorCode, innerError) {
        super(message);
        this.errorCode = errorCode;
        this.name = this.constructor.name;
        this.innerError = ensureError(innerError);
    }
}
exports.TransactionalOutboxInboxError = TransactionalOutboxInboxError;
/** An error that was raised when handling an outbox/inbox message. */
class MessageError extends TransactionalOutboxInboxError {
    constructor(message, errorCode, messageObject, innerError) {
        super(message, errorCode, innerError);
        this.messageObject = messageObject;
        this.name = this.constructor.name;
    }
}
exports.MessageError = MessageError;
/**
 * Returns the error as verified Error object or wraps the input as
 * ExtendedError with error code and potential innerError.
 * @param error The error variable to check
 * @returns The error if the input was already an error otherwise a wrapped error. Enriched with the error code property.
 */
const ensureExtendedError = (error, fallbackErrorCode) => {
    if (error instanceof TransactionalOutboxInboxError) {
        return error;
    }
    const err = ensureError(error);
    err.errorCode = fallbackErrorCode;
    return err;
};
exports.ensureExtendedError = ensureExtendedError;
const ensureError = (error) => {
    if (error === null || error === undefined) {
        return undefined;
    }
    if (error instanceof Error) {
        return error;
    }
    return new Error(String(error));
};
//# sourceMappingURL=error.js.map